<?php
/**
 *
 * @var $is_woocommerce_reviews_disabled_globally
 */
if ( ! defined( 'ABSPATH' ) ) exit;
global $wpdb;
$product_review_request_bg = $wpdb->get_results( "SELECT option_value FROM $wpdb->options WHERE option_name LIKE '%wp_wtsr_review_request_batch%'", ARRAY_A );
$is_ts_review_request_enabled = '';

if (!empty($product_review_request_bg)) {
    $product_review_request_bg_count = count($product_review_request_bg);
} else {
    $is_ts_review_request_enabled = get_option('wtsr_ts_review_request_enabled');
}

$order_statuses = wc_get_order_statuses();

$selected_order_status = !empty($_GET['wtsr_filter_status']) ? sanitize_text_field($_GET['wtsr_filter_status']) : '';
$start_order_date = !empty($_GET['wtsr_start_order_date']) ? sanitize_text_field($_GET['wtsr_start_order_date']) : date('Y-m-d', (time() - (7 * 24 * 60 * 60)));
$end_order_date = !empty($_GET['wtsr_end_order_date']) ? sanitize_text_field($_GET['wtsr_end_order_date']) : date('Y-m-d', time());

if (empty($selected_order_status)) {
    $selected_order_status = get_option('wtsr_order_status', 'wc-completed');
}

if ('wc-order-created' === $selected_order_status) {
    $selected_order_status = 'wc-completed';
}

$end_order_date_label = strtotime($end_order_date) + (24 * 60 * 60);

$args = array(
    'limit' => 1000,
    'type' => 'shop_order',
    'status' => str_replace('wc-', '', $selected_order_status),
    'date_created' => strtotime($start_order_date) . '...' . $end_order_date_label,
);
$orders = wc_get_orders( $args );
$reviews = ReviewsModel::get_all_by('order_id');
$orders_count = 0;

ob_start();
$limit_allowed = true;

if ('free' === Wtsr_License::get_license_version()) {
    $get_limit_allowed = TSManager::get_limit_allowed();

    if (empty($get_limit_allowed)) {
        $limit_allowed = false;
    }
}

if (!empty($orders)) {
    $emails_array = array();

    foreach ($orders as $order) {
        $order_id = $order->get_id();
        $buyer = '';

        if ( $order->get_billing_first_name() || $order->get_billing_last_name() ) {
            /* translators: 1: first name 2: last name */
            $buyer = trim( sprintf( _x( '%1$s %2$s', 'full name', 'woocommerce' ), $order->get_billing_first_name(), $order->get_billing_last_name() ) );
        } elseif ( $order->get_billing_company() ) {
            $buyer = trim( $order->get_billing_company() );
        } elseif ( $order->get_customer_id() ) {
            $user  = get_user_by( 'id', $order->get_customer_id() );
            $buyer = ucwords( $user->display_name );
        }

        $email = $order->get_billing_email();

        if (in_array($email, $emails_array)) {
            $email = false;
        } else {
            $emails_array[] = $email;
            $existed_email = ReviewsModel::get_last_by_email($email);

            if (!empty($existed_email)) {
                $review_id = $existed_email['id'];
                $outdated = TSManager::maybe_review_outdated($review_id);

                if (!$outdated) {
                    $email = false;
                }
            }
        }

        $existed_review = !empty($reviews[$order_id]) ? $reviews[$order_id] : false;
        $order_created_via = TSManager::get_created_via($order);
        $is_amazon = strpos($order_created_via, 'amazon');
        $is_ebay = strpos($order_created_via, 'ebay');
        $is_on_checkout = $order_created_via === 'checkout';

        if ($is_on_checkout && !empty($email) && TSManager::is_email_valid($email) && empty($existed_review)) {
            ?>
            <tr>
                <th class="check-column">
                    <input id="cb-select-<?php echo $order->get_id(); ?>" type="checkbox" value="<?php echo $order_id; ?>">
                </th>

                <td class="column-primary has-row-actions">
                    <strong>#<?php echo $order_id . ' ' . $buyer; ?></strong>

                    <button type="button" class="toggle-row"><span class="screen-reader-text">Show more details</span></button>
                </td>
                <td data-colname="<?php _e('Status', 'more-better-reviews-for-woocommerce'); ?>"><?php echo $order->get_status(); ?></td>
                <td data-colname="<?php _e('Email', 'more-better-reviews-for-woocommerce'); ?>"><?php echo $email; ?></td>
                <td data-colname="<?php _e('Created', 'more-better-reviews-for-woocommerce'); ?>"><?php echo date('Y-m-d', strtotime($order->get_date_created())); ?></td>
                <td data-colname="">
                    <button
                        type="button"
                        class="button button-primary button-small generate-review"
                        data-order-id="<?php echo $order_id; ?>"
                        <?php echo !empty($product_review_request_bg) || !$limit_allowed ? ' disabled' : ''; ?>
                    >
                        <?php _e('Generate request', 'more-better-reviews-for-woocommerce'); ?>
                    </button>
                </td>
            </tr>
            <?php

            $orders_count++;
        }
    }
}

$orders_list = ob_get_clean();
?>

<div class="wtsr-page-header with-btn-holder">
    <h3><?php _e('Generate requests', 'more-better-reviews-for-woocommerce'); ?></h3>

    <div class="buttons-holder">
        <span style="display:inline-block;line-height:28px;margin:0 5px 0 0;">
            <strong><?php _e( 'Next step', 'more-better-reviews-for-woocommerce' ) ?>:</strong>
        </span>

        <a href="?page=wp2leads-wtsr&tab=reviews" class="button button-success">
            <?php _e('View generated requests', 'more-better-reviews-for-woocommerce') ?>
        </a>
    </div>
</div>

<?php
if (!empty($product_review_request_bg)) {
    ?>
    <div class="notice notice-warning inline">
        <p>
            <?php _e("You can't generate reviews requests for existed orders right now, as far as some requests are running in background." , 'more-better-reviews-for-woocommerce') ?>
        </p>
    </div>
    <?php
}
?>

<div style="margin-bottom:15px;">
    <?php
    if ('woocommerce' !== $wtsr_email_send_via) {
        ?>
        <?php _e("Enable auto generate and transfer review requests" , 'more-better-reviews-for-woocommerce') ?>:
        <?php
    } else {
        ?>
        <?php _e("Enable auto generate and email review requests" , 'more-better-reviews-for-woocommerce') ?>:
        <?php
    }
    ?>
    <select name="wtsr_ts_enable_review_request" id="wtsr_ts_enable_review_request" class="form-input" style="max-width:120px;display:inline-block;margin-left:10px;">
        <option value="yes"<?php echo $is_ts_review_request_enabled ? ' selected' : ''; ?>><?php _e('Enabled', 'more-better-reviews-for-woocommerce'); ?></option>
        <option value="no"<?php echo !$is_ts_review_request_enabled ? ' selected' : ''; ?>><?php _e('Disabled', 'more-better-reviews-for-woocommerce'); ?></option>
    </select>

    <button id="wtsr_ts_enable_review_request_btn" type="button" class="button button-primary" style="height:34px;line-height:32px;">
        <?php _e('Save', 'more-better-reviews-for-woocommerce'); ?>
    </button>
</div>

<div id="reviews_actions" style="margin-bottom:15px;">
    <p>
        <strong><?php _e('Generate review requests for existed orders', 'more-better-reviews-for-woocommerce'); ?></strong>
        (<?php echo $orders_count . ' ' . __('orders available', 'more-better-reviews-for-woocommerce'); ?>)
    </p>
    <form method="get">
        <div id="filter_actions" style="margin-bottom:10px;">
            <input type="hidden" name="page" value="wp2leads-wtsr">
            <input type="hidden" name="tab" value="generate">

            <?php
            if (!empty($order_statuses)) {
                ?>
                <?php _e('Order status', 'more-better-reviews-for-woocommerce'); ?>:
                <select name="wtsr_filter_status" id="wtsr_filter_status" class="form-input" style="max-width:160px;display:inline-block;margin-right:20px;">
                    <?php
                    foreach ($order_statuses as $slug => $label) {
                        ?>
                        <option value="<?php echo $slug ?>"<?php echo $slug === $selected_order_status ? ' selected' : ''; ?>><?php echo $label ?></option>
                        <?php
                    }
                    ?>
                </select>
                <?php _e('Start / End dates', 'more-better-reviews-for-woocommerce'); ?>:
                <input id="wtsr_start_order_date" name="wtsr_start_order_date" type="text"
                       value="<?php echo $start_order_date; ?>"
                       class="wtsr-datepicker form-input" style="max-width:120px;display:inline-block;" readonly> -

                <input id="wtsr_end_order_date" name="wtsr_end_order_date" type="text"
                       value="<?php echo $end_order_date; ?>"
                       class="wtsr-datepicker form-input" style="max-width:120px;display:inline-block;" readonly>

                <button type="submit" class="button button-primary" style="height:34px;line-height:32px;">
                    <?php _e('Filter', 'more-better-reviews-for-woocommerce'); ?>
                </button>

                <button
                    id="generate_selected_reviews"
                    class="button button-primary"
                    type="button"
                    data-warningmsg="<?php _e('Are you sure you want to generate requests for selected orders', 'more-better-reviews-for-woocommerce'); ?>"
                    data-notselectedmsg="<?php _e('Select at least one order', 'more-better-reviews-for-woocommerce'); ?>"
                    style="height:34px;line-height:32px;"
                    <?php echo !empty($product_review_request_bg) || !$limit_allowed ? ' disabled' : ''; ?>
                >
                    <?php _e('Generate for selected', 'more-better-reviews-for-woocommerce'); ?>
                </button>
                <?php
            }
            ?>

        </div>
    </form>
</div>

<table class="wp-list-table widefat fixed striped pages">
    <thead>
    <tr>
        <td class="manage-column column-cb check-column">
            <label class="screen-reader-text" for="cb-select-all-1"><?php echo __( 'Select All', 'more-better-reviews-for-woocommerce' ) ?></label>
            <input id="cb-select-all-1" type="checkbox" />
        </td>
        <th class="column-primary"><?php _e('Order', 'more-better-reviews-for-woocommerce'); ?></th>
        <th><?php _e('Status', 'more-better-reviews-for-woocommerce'); ?></th>
        <th><?php _e('Email', 'more-better-reviews-for-woocommerce'); ?></th>
        <th><?php _e('Created', 'more-better-reviews-for-woocommerce'); ?></th>
        <th></th>
    </tr>
    </thead>

    <tbody id="the-list">
    <?php echo $orders_list; ?>
    </tbody>

    <tfoot>
    <tr>
        <td class="manage-column column-cb check-column">
            <label class="screen-reader-text" for="cb-select-all-2"><?php echo __( 'Select All', 'more-better-reviews-for-woocommerce' ) ?></label>
            <input id="cb-select-all-2" type="checkbox" />
        </td>
        <th class="column-primary"><?php _e('Order', 'more-better-reviews-for-woocommerce'); ?></th>
        <th><?php _e('Status', 'more-better-reviews-for-woocommerce'); ?></th>
        <th><?php _e('Email', 'more-better-reviews-for-woocommerce'); ?></th>
        <th><?php _e('Created', 'more-better-reviews-for-woocommerce'); ?></th>
        <th></th>
    </tr>
    </tfoot>
</table>

<div class="wtsr-page-footer">

</div>
