<?php

/**
 * Provide a admin area view for the plugin
 *
 * This file is used to markup the admin-facing aspects of the plugin.
 *
 * @since      0.0.1
 *
 * @package    Wtsr
 * @subpackage Wtsr/admin/partials
 */

if ( ! defined( 'ABSPATH' ) ) exit;
global $wpdb;

$order_statuses = wc_get_order_statuses();
$filter_emails = get_option('wtsr_filter_email_domain', '');

$selected_order_status = !empty($_GET['wtsr_filter_status']) ? trim($_GET['wtsr_filter_status']) : '';
$start_order_date = !empty($_GET['wtsr_start_order_date']) ? trim($_GET['wtsr_start_order_date']) : date('Y-m-d', (time() - (7 * 24 * 60 * 60)));
$end_order_date = !empty($_GET['wtsr_end_order_date']) ? trim($_GET['wtsr_end_order_date']) : date('Y-m-d', time());

if (empty($selected_order_status)) {
    $selected_order_status = get_option('wtsr_order_status', 'wc-completed');
}

if ('wc-order-created' === $selected_order_status) {
    $selected_order_status = 'wc-completed';
}

$post_status = str_replace('wc-', '', $selected_order_status);

$start_order_date_label = strtotime($start_order_date);
$end_order_date_label = strtotime($end_order_date) + (24 * 60 * 60);

// Check if any orders in our db available
$is_orders_available = false;

if (!empty(TSManager::is_any_orders_available())) {
    $is_orders_available = true;
}

if (!empty($is_orders_available)) {
    $sql = "
SELECT p.ID, p.post_status, p.post_type, pm.*, GROUP_CONCAT(DISTINCT pm.meta_value SEPARATOR ', ') AS meta
FROM {$wpdb->posts} AS p
LEFT JOIN {$wpdb->postmeta} as pm ON p.ID = pm.post_id
WHERE post_type = 'shop_order'
AND post_status NOT IN ('trash')
AND (
	(pm.meta_key IN ('_billing_email', '_created_via'))
)";

    $post_created_from = date('Y-m-d', $start_order_date_label) . ' 00:00:00';
    $post_created_till = date('Y-m-d', $end_order_date_label) . ' 00:00:00';

    if (!empty($post_created_from) && $post_created_till) {
        $sql .= " AND ( ( p.post_date_gmt >= '{$post_created_from}' AND p.post_date_gmt <= '{$post_created_till}' ) )";
    }


if (!empty($post_status)) {
    $sql .= "
AND post_status = '{$selected_order_status}'";
}

    $sql .= "
GROUP BY p.ID
HAVING meta LIKE '%checkout%' AND meta NOT LIKE '%amazon%' AND meta NOT LIKE '%ebay%'";

    if (!empty($filter_emails && is_array($filter_emails))) {
        foreach ($filter_emails as $filter_email) {
            $sql .= " AND meta NOT LIKE '%{$filter_email}%'";
        }
    }

    $result = $wpdb->get_results($sql, ARRAY_A);

    $orders = array();

    if (!empty($result)) {
        foreach ($result as $order_data) {
            $order = wc_get_order( $order_data['ID'] );

            if (!empty($order)) {
                $orders[] = $order;
            }
        }
    }
}

$license_info = Wtsr_License::get_lecense_info();
$activation_in_progress = get_transient( 'wtsr_activation_in_progress' );
$user_limit = get_option('wtsr_limit_users');
$days_limit = get_option('wtsr_limit_days');
$license_version = Wtsr_License::get_license_version();

?>
<div style="width:100%;max-width:750px;margin-left:auto;margin-right:auto;">
    <p>
        <?php _e("Congratulations you managed a lot.</br>At this step you can generate review requests from your current orders and activate automatic mode." , 'more-better-reviews-for-woocommerce') ?>
    </p>

    <?php
    // Check if license is free
    $license_version = Wtsr_License::get_license_version();

    if ('free' === $license_version) {
        $user_limit = get_option('wtsr_limit_users');
        $days_limit = get_option('wtsr_limit_days');
        $user_count = get_option('wtsr_limit_count', 0);
        $user_count_timeout = get_option('wtsr_limit_count_timeout', 0);
        $timeout_label = '';

        if (!empty($user_count_timeout)) {
            $user_count_timeout_left = $user_count_timeout - time();

            if ($user_count_timeout_left > 86400) {
                $timeout_left = ceil($user_count_timeout_left / 86400);
                $timeout_label = $timeout_left . ' ' . __(' days', 'more-better-reviews-for-woocommerce');
            } else {
                $timeout_left = ceil($user_count_timeout_left / 3600);
                $timeout_label = $timeout_left . ' ' . __(' hours', 'more-better-reviews-for-woocommerce');
            }
        }

        $user_left = (int) $user_limit - (int) $user_count;

        ?>
        <div class="notice notice-warning inline" style="margin-bottom:15px;width:100%;max-width:750px;margin-left:auto;margin-right:auto;">
            <p>
                <?php _e('You can use More Better Reviews for WooCommerce for free and see you reviews created from you current and new WooCommerce customers and transfer them to Klick Tipp.', 'more-better-reviews-for-woocommerce'); ?>
                <?php
                $string = __( 'Lifetime free usage of all features with a limitation for <strong>%s reviews</strong> sent per <strong>%s days</strong>.', 'more-better-reviews-for-woocommerce' );
                echo sprintf($string , $user_limit, $days_limit );
                ?>
            </p>

            <p>
                <?php
                if (0 > $user_left || 0 === $user_left) {
                    $string = __( 'You have exceeded your Pro Version limit for %s reviews per %s days.', 'more-better-reviews-for-woocommerce' );
                    echo sprintf($string , $user_limit, $days_limit );
                } else {
                    $string = __( 'You still have %s out of %s-review requests you can generate. (Reset every %s days)', 'more-better-reviews-for-woocommerce' );
                    echo sprintf($string , $user_left, $user_limit, $days_limit );
                }

                echo ' ' . __( '</br>Wait without generating new review requests or get a license for unlimited review requests <a href="https://wp2leads-for-klick-tipp.com/web/better-reviews-for-woocommerce-price-list-eng/" target="_blank">here</a>.', 'more-better-reviews-for-woocommerce' );

                if (!empty($timeout_label)) {
                    $string = __( 'Limit will be reset in <strong>%s</strong>.', 'more-better-reviews-for-woocommerce' );
                    echo ' ' . sprintf($string , $timeout_label );
                }
                ?>
            </p>
        </div>
        <?php
    }
    ?>

    <?php require_once dirname(__FILE__) . '/wtsr-admin-wizard-block-license_info.php'; ?>
</div>
<?php

if (empty($is_orders_available)) {
    ?>
    <div class="wtsr-processing-holder" style="padding:10px;">
        <div class="notice notice-warning inline" style="margin-bottom:15px;width:100%;max-width:750px;margin-left:auto;margin-right:auto;">
            <p>
                <?php _e("You do not have any customers orders in your DB." , 'more-better-reviews-for-woocommerce') ?>
                <br>
                <?php _e("You can generate 5 dummy orders for testing purposes by clicking the button <strong>Generate orders</strong>." , 'more-better-reviews-for-woocommerce') ?>
                <br>
                <?php _e("It could take a few seconds, please be patient and do not reload or close this page." , 'more-better-reviews-for-woocommerce') ?>
            </p>
        </div>

        <div class="settings-container">
            <div class="settings-control">
                <button id="wizard-wtsr_generate_orders" class="button button-primary" type="button">
                    <?php _e('Generate 5 Orders', 'more-better-reviews-for-woocommerce'); ?>
                </button>
            </div>
        </div>

        <div class="wtsr-spinner-holder">
            <div class="wtsr-spinner"></div>
        </div>
    </div>
    <?php
} else {
    global $wpdb;
    $product_review_request_bg = $wpdb->get_results( "SELECT option_value FROM $wpdb->options WHERE option_name LIKE '%wp_wtsr_review_request_batch%'", ARRAY_A );

    if (!empty($product_review_request_bg)) {
        $product_review_request_bg_count = count($product_review_request_bg);
    } else {
        $is_ts_review_request_enabled = get_option('wtsr_ts_review_request_enabled');
    }

    $reviews = ReviewsModel::get_all_by('order_id');
    $orders_count = 0;

    ob_start();

    if (!empty($orders)) {
        $emails_array = array();

        foreach ($orders as $order) {
            $order_id = $order->get_id();
            $buyer = '';

            if ( $order->get_billing_first_name() || $order->get_billing_last_name() ) {
                /* translators: 1: first name 2: last name */
                $buyer = trim( sprintf( _x( '%1$s %2$s', 'full name', 'woocommerce' ), $order->get_billing_first_name(), $order->get_billing_last_name() ) );
            } elseif ( $order->get_billing_company() ) {
                $buyer = trim( $order->get_billing_company() );
            } elseif ( $order->get_customer_id() ) {
                $user  = get_user_by( 'id', $order->get_customer_id() );
                $buyer = ucwords( $user->display_name );
            }

            $email = $order->get_billing_email();

            if (in_array($email, $emails_array)) {
                $email = false;
            } else {
                $emails_array[] = $email;
                $existed_email = ReviewsModel::get_last_by_email($email);

                if (!empty($existed_email)) {
                    $review_id = $existed_email['id'];
                    $outdated = TSManager::maybe_review_outdated($review_id);

                    if (!$outdated) {
                        $email = false;
                    }
                }
            }

            $existed_review = !empty($reviews[$order_id]) ? $reviews[$order_id] : false;
            $order_created_via = TSManager::get_created_via($order);
            $is_amazon = strpos($order_created_via, 'amazon');
            $is_ebay = strpos($order_created_via, 'ebay');
            $is_on_checkout = $order_created_via === 'checkout';

            if ($is_on_checkout && !empty($email) && TSManager::is_email_valid($email) && empty($existed_review)) {
                ?>
                <tr>
                    <th class="check-column">
                        <?php
                        if ('free' === $license_version && 0 === $user_left) {

                        } else {
                            ?>
                            <input id="cb-select-<?php echo $order->get_id(); ?>" type="checkbox" value="<?php echo $order_id; ?>">
                            <?php
                        }
                        ?>
                    </th>

                    <td class="column-primary has-row-actions">
                        <strong>#<?php echo $order_id . ' ' . $buyer; ?></strong>

                        <button type="button" class="toggle-row"><span class="screen-reader-text">Show more details</span></button>
                    </td>
                    <td data-colname="<?php _e('Status', 'more-better-reviews-for-woocommerce'); ?>"><?php echo $order->get_status(); ?></td>
                    <td data-colname="<?php _e('Email', 'more-better-reviews-for-woocommerce'); ?>"><?php echo $email; ?></td>
                    <td data-colname="<?php _e('Created', 'more-better-reviews-for-woocommerce'); ?>"><?php echo date('Y-m-d', strtotime($order->get_date_created())); ?></td>
                    <td data-colname="">
                        <?php
                        if ('free' === $license_version && 0 === $user_left) {
                            ?>
                            <button
                                    type="button"
                                    class="button button-primary button-small generate-review"
                                    data-order-id="<?php echo $order_id; ?>"
                                    disabled
                            >
                                <?php _e('Generate request', 'more-better-reviews-for-woocommerce'); ?>
                            </button>
                            <?php
                        } else {
                            ?>
                            <button
                                    type="button"
                                    class="button button-primary button-small generate-review"
                                    data-order-id="<?php echo $order_id; ?>"
                                <?php echo !empty($product_review_request_bg) ? ' disabled' : ''; ?>
                            >
                                <?php _e('Generate request', 'more-better-reviews-for-woocommerce'); ?>
                            </button>
                            <?php
                        }
                        ?>
                    </td>
                </tr>
                <?php

                $orders_count++;
            }
        }
    }

    $orders_list = ob_get_clean();

    if (!empty($product_review_request_bg)) {
        ?>
        <div class="notice notice-warning inline">
            <p>
                <?php _e("You can't generate reviews requests for existed orders right now, as far as some requests are running in background." , 'more-better-reviews-for-woocommerce') ?>
            </p>
        </div>
        <?php
    }
    ?>
    <div id="reviews_actions" style="margin-bottom:15px;">
        <p>
            <strong><?php _e('Generate review requests for existed orders', 'more-better-reviews-for-woocommerce'); ?></strong>
            (<?php echo $orders_count . ' ' . __('orders available', 'more-better-reviews-for-woocommerce'); ?>)
        </p>
        <form method="get">
            <div id="filter_actions" style="margin-bottom:10px;">
                <input type="hidden" name="page" value="wp2leads-wtsr">
                <input type="hidden" name="tab" value="wizard">
                <input type="hidden" name="wizard_step" value="generate_reviews">

                <?php
                if (!empty($order_statuses)) {
                    ?>
                    <?php _e('Order status', 'more-better-reviews-for-woocommerce'); ?>:
                    <select name="wtsr_filter_status" id="wtsr_filter_status" class="form-input" style="max-width:160px;display:inline-block;margin-right:20px;">
                        <?php
                        foreach ($order_statuses as $slug => $label) {
                            ?>
                            <option value="<?php echo $slug ?>"<?php echo $slug === $selected_order_status ? ' selected' : ''; ?>><?php echo $label ?></option>
                            <?php
                        }
                        ?>
                    </select>
                    <?php _e('Start / End dates', 'more-better-reviews-for-woocommerce'); ?>:
                    <input id="wtsr_start_order_date" name="wtsr_start_order_date" type="text"
                           value="<?php echo $start_order_date; ?>"
                           class="wtsr-datepicker form-input" style="max-width:120px;display:inline-block;" readonly> -

                    <input id="wtsr_end_order_date" name="wtsr_end_order_date" type="text"
                           value="<?php echo $end_order_date; ?>"
                           class="wtsr-datepicker form-input" style="max-width:120px;display:inline-block;" readonly>

                    <button type="submit" class="button button-primary" style="height:34px;line-height:32px;">
                        <?php _e('Filter', 'more-better-reviews-for-woocommerce'); ?>
                    </button>

                    <?php
                    if ('free' === $license_version && 0 === $user_left) {
                        ?>
                        <button
                                id="generate_selected_reviews"
                                class="button button-primary"
                                type="button"
                                data-warningmsg="<?php _e('Are you sure you want to generate requests for selected orders', 'more-better-reviews-for-woocommerce'); ?>"
                                data-notselectedmsg="<?php _e('Select at least one order', 'more-better-reviews-for-woocommerce'); ?>"
                                disabled
                                style="height:34px;line-height:32px;"
                        >
                            <?php _e('Generate for selected', 'more-better-reviews-for-woocommerce'); ?>
                        </button>
                        <?php
                    } else {
                        ?>
                        <button
                                id="generate_selected_reviews"
                                class="button button-primary"
                                type="button"
                                data-warningmsg="<?php _e('Are you sure you want to generate requests for selected orders', 'more-better-reviews-for-woocommerce'); ?>"
                                data-notselectedmsg="<?php _e('Select at least one order', 'more-better-reviews-for-woocommerce'); ?>"
                                style="height:34px;line-height:32px;"
                        >
                            <?php _e('Generate for selected', 'more-better-reviews-for-woocommerce'); ?>
                        </button>
                        <?php
                    }
                    ?>
                    <?php
                }
                ?>

            </div>
        </form>
    </div>

    <?php
    if (empty($orders_count) && empty($reviews)) {
        ?>
        <div class="wtsr-processing-holder" style="padding:10px;">
            <div class="notice notice-warning inline" style="margin-bottom:15px;">
                <p>
                    <?php echo sprintf(__('Your do not have orders with status <strong>%s</strong> created in period between <strong>%s</strong> -  <strong>%s</strong>.', 'more-better-reviews-for-woocommerce') , $selected_order_status, $start_order_date, $end_order_date ); ?>
                    <?php _e("You can select another order status or change date period." , 'more-better-reviews-for-woocommerce') ?>
                    <br>
                    <?php _e("Or you can generate 5 dummy orders for testing purposes by clicking the button <strong>Generate orders</strong>." , 'more-better-reviews-for-woocommerce') ?>
                    <?php
                    if ('free' === $license_version) {
                        ?>
                        <?php _e("Dummy orders <strong>will not affect</strong> your Pro Version limitation." , 'more-better-reviews-for-woocommerce') ?>
                        <?php
                    }
                    ?>
                    <br>
                    <?php _e("It could take a few seconds, please be patient and do not reload or close this page." , 'more-better-reviews-for-woocommerce') ?>
                </p>
            </div>

            <div class="settings-container">
                <div class="settings-control">
                    <button id="wizard-wtsr_generate_orders" class="button button-primary" type="button" data-status="<?php echo $selected_order_status; ?>">
                        <?php _e('Generate 5 Orders', 'more-better-reviews-for-woocommerce'); ?>
                    </button>
                </div>
            </div>

            <div class="wtsr-spinner-holder">
                <div class="wtsr-spinner"></div>
            </div>
        </div>
        <?php
    } else {
        ?>
        <table class="wp-list-table widefat fixed striped pages">
            <thead>
            <tr>
                <td class="manage-column column-cb check-column">
                    <?php
                    if ('free' === $license_version && 0 === $user_left) {
                        ?>
                        <?php
                    } else {
                        ?>
                        <label class="screen-reader-text" for="cb-select-all-1"><?php echo __( 'Select All', 'more-better-reviews-for-woocommerce' ) ?></label>
                        <input id="cb-select-all-1" type="checkbox" />
                        <?php
                    }
                    ?>
                </td>
                <th class="column-primary"><?php _e('Order', 'more-better-reviews-for-woocommerce'); ?></th>
                <th><?php _e('Status', 'more-better-reviews-for-woocommerce'); ?></th>
                <th><?php _e('Email', 'more-better-reviews-for-woocommerce'); ?></th>
                <th><?php _e('Created', 'more-better-reviews-for-woocommerce'); ?></th>
                <th></th>
            </tr>
            </thead>

            <tbody id="the-list">
            <?php echo $orders_list; ?>
            </tbody>

            <tfoot>
            <tr>
                <td class="manage-column column-cb check-column">
                    <?php
                    if ('free' === $license_version && 0 === $user_left) {
                        ?>
                        <?php
                    } else {
                        ?>
                        <label class="screen-reader-text" for="cb-select-all-1"><?php echo __( 'Select All', 'more-better-reviews-for-woocommerce' ) ?></label>
                        <input id="cb-select-all-1" type="checkbox" />
                        <?php
                    }
                    ?>
                </td>
                <th class="column-primary"><?php _e('Order', 'more-better-reviews-for-woocommerce'); ?></th>
                <th><?php _e('Status', 'more-better-reviews-for-woocommerce'); ?></th>
                <th><?php _e('Email', 'more-better-reviews-for-woocommerce'); ?></th>
                <th><?php _e('Created', 'more-better-reviews-for-woocommerce'); ?></th>
                <th></th>
            </tr>
            </tfoot>
        </table>
        <?php
    }
}
?>

