<?php

/**
 * Helpers library functions
 *
 * @since      0.0.1
 *
 * @package    Wtsr
 * @subpackage Wtsr/includes
 */

if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * wcj_is_plugin_activated.
 *
 * @version 0.0.1
 * @since   0.0.1
 * @return  bool
 */
function wtsr_is_plugin_activated( $plugin_folder, $plugin_file ) {
    if ( wtsr_is_plugin_active_simple( $plugin_folder . '/' . $plugin_file ) ) {
        return true;
    } else {
        return wtsr_is_plugin_active_by_file( $plugin_file );
    }
}

/**
 * wcj_is_plugin_active_simple.
 *
 * @version 0.0.1
 * @since   0.0.1
 * @return  bool
 */
function wtsr_is_plugin_active_simple( $plugin ) {
    return (
        in_array( $plugin, apply_filters( 'active_plugins', get_option( 'active_plugins', array() ) ) ) ||
        ( is_multisite() && array_key_exists( $plugin, get_site_option( 'active_sitewide_plugins', array() ) ) )
    );
}

/**
 * wcj_is_plugin_active_by_file.
 *
 * @version 0.0.1
 * @since   0.0.1
 * @return  bool
 */
function wtsr_is_plugin_active_by_file( $plugin_file ) {
    foreach ( wtsr_get_active_plugins() as $active_plugin ) {
        $active_plugin = explode( '/', $active_plugin );

        if ( isset( $active_plugin[1] ) && $plugin_file === $active_plugin[1] ) {
            return true;
        }
    }

    return false;
}

/**
 * wcj_get_active_plugins.
 *
 * @version 0.0.1
 * @since   0.0.1
 * @return  array
 */
function wtsr_get_active_plugins() {
    $active_plugins = apply_filters( 'active_plugins', get_option( 'active_plugins', array() ) );
    if ( is_multisite() ) {
        $active_plugins = array_merge( $active_plugins, array_keys( get_site_option( 'active_sitewide_plugins', array() ) ) );
    }
    return $active_plugins;
}

/**
 * Show templates passing attributes and including the file.
 *
 * @param string $template_name
 * @param array $args
 * @param string $template_path
 */
function wtsr_show_template($template_name, $args = array(), $template_path = 'public/partials')
{
    if (!empty($args) && is_array($args)) {
        extract($args);
    }

    $located = wtsr_locate_template($template_name, $template_path);

    if (!file_exists($located)) {
        return;
    }

    include($located);
}

/**
 * Like show, but returns the HTML instead of outputting.
 *
 * @param $template_name
 * @param array $args
 * @param string $template_path
 * @param string $default_path
 *
 * @return string
 */
function wtsr_get_template($template_name, $args = array(), $template_path = 'public/partials')
{
    ob_start();
    wtsr_show_template($template_name, $args, $template_path);
    return ob_get_clean();
}

/**
 * Locate a template and return the path for inclusion.
 *
 * @param $template_name
 * @param string $template_path
 * @return string
 */
function wtsr_locate_template($template_name, $template_path = 'public/partials/')
{
    if (!$template_path) {
        $template_path = 'public/partials/';
    }

    $template_path = untrailingslashit( plugin_dir_path( WTSR_PLUGIN_FILE ) ) . '/public/partials/';

    $template = locate_template(
        array(
            trailingslashit($template_path) . $template_name,
            $template_name
        )
    );

    // Get default template/.
    if ( ! $template ) {
        $template = $template_path . $template_name;
    }

    return $template;
}