<?php
/**
 * DB Reviews Model
 *
 * @since      0.0.1
 *
 * @package    Wtsr
 * @subpackage Wtsr/includes/lib
 */

class ReviewsModel {
    /**
     * Table name in the database
     *
     * @var string
     */
    private static $table_name = 'wp2lwtsr_reviews';

    private static function get_schema() {
        global $wpdb;

        $table_name = $wpdb->prefix . self::$table_name;

        $collate = '';

        if ( $wpdb->has_cap( 'collation' ) ) {
            $collate = $wpdb->get_charset_collate();
        }

        $sql = "
CREATE TABLE {$table_name} (
  id BIGINT UNSIGNED NOT NULL auto_increment,
  order_id BIGINT UNSIGNED NOT NULL DEFAULT 0,
  email varchar(100) NOT NULL,
  status varchar(15) NOT NULL,
  review_link text NOT NULL,
  review_message mediumtext NOT NULL,
  review_created datetime NOT NULL default '0000-00-00 00:00:00',
  review_sent datetime NULL default null,
  PRIMARY KEY  (id),
  UNIQUE KEY order_email (order_id,email)
) $collate;
        ";

        return $sql;
    }

    public static function get($id) {
        global $wpdb;

        $table = $wpdb->prefix . self::$table_name;

        $sql = "SELECT * FROM {$table} WHERE id = '".$id."' ORDER BY id DESC LIMIT 1";

        return $wpdb->get_results( $sql );
    }

    public static function get_by_id($id) {
        global $wpdb;

        $table = $wpdb->prefix . self::$table_name;

        $sql = "SELECT * FROM {$table} WHERE id = '".$id."' ORDER BY id DESC LIMIT 1";

        return $wpdb->get_row( $sql, ARRAY_A );
    }

    public static function get_by_order_id($order_id) {
        global $wpdb;

        $table = $wpdb->prefix . self::$table_name;

        $sql = "SELECT * FROM {$table} WHERE order_id = '".$order_id."' ORDER BY id DESC LIMIT 1";

        return $wpdb->get_results( $sql );
    }

    public static function get_all($order = 'DESC') {
        global $wpdb;

        $table = $wpdb->prefix . self::$table_name;

        $sql = "SELECT * FROM {$table} ORDER BY id " . $order;

        return $wpdb->get_results( $sql );
    }

    public static function get_with_template($order = 'DESC', $args = array()) {
        global $wpdb;

        $table = $wpdb->prefix . self::$table_name;

        $sql = "SELECT * FROM {$table} WHERE status NOT IN ('pending')";

        if (!empty($args['created_from']) && !empty($args['created_till'])) {
            $sql .= " AND ( ( review_created >= '{$args['created_from']}' AND review_created <= '{$args['created_till']}' ) )";
        } else if (!empty($args['created_from'])) {
            $sql .= " AND review_created >= '{$args['created_from']}'";
        } else if (!empty($args['created_till'])) {
            $sql .= " AND review_created <= '{$args['created_till']}'";
        }

        $sql .= " ORDER BY id " . $order;

        return $wpdb->get_results( $sql );
    }

    public static function get_all_by($group_by = false) {
        global $wpdb;

        $table = $wpdb->prefix . self::$table_name;

        $sql = "SELECT * FROM {$table} ORDER BY id DESC";

        $result = $wpdb->get_results( $sql, ARRAY_A );

        if (!empty($result) && !empty($group_by) && in_array($group_by, array('id', 'order_id', 'email'))) {
            $temp_result = array();

            foreach ($result as $item) {
                $temp_result[$item[$group_by]] = $item;
            }

            $result = $temp_result;
        }

        return $result;
    }

    public static function get_last_by_email($email) {
        global $wpdb;

        $table = $wpdb->prefix . self::$table_name;

        $sql = "SELECT * FROM {$table} WHERE email = '".$email."' ORDER BY id DESC LIMIT 1";

        return $wpdb->get_row( $sql, ARRAY_A );
    }

    public static function get_not_reviewed($group_by = false) {
        global $wpdb;

        $table = $wpdb->prefix . self::$table_name;

        $sql = "SELECT * FROM {$table} WHERE status IN ('transferred', 'transfered') ORDER BY id DESC";

        $result = $wpdb->get_results( $sql, ARRAY_A);

        if (!empty($result) && !empty($group_by) && in_array($group_by, array('id', 'order_id', 'email'))) {
            $temp_result = array();

            foreach ($result as $item) {
                $temp_result[$item[$group_by]] = $item;
            }

            $result = $temp_result;
        }

        return $result;
    }

    public static function get_finished($group_by = false) {
        global $wpdb;

        $table = $wpdb->prefix . self::$table_name;

        $sql = "SELECT * FROM {$table} WHERE status IN ('outdated', 'reviewed') ORDER BY id DESC";

        $result = $wpdb->get_results( $sql, ARRAY_A);

        if (!empty($result) && !empty($group_by) && in_array($group_by, array('id', 'order_id', 'email'))) {
            $temp_result = array();

            foreach ($result as $item) {
                $temp_result[$item[$group_by]] = $item;
            }

            $result = $temp_result;
        }

        return $result;
    }

    public static function create($data) {
        global $wpdb;

        $table = $wpdb->prefix . self::$table_name;

        $wpdb->insert( $table, $data );

        $id = (int) $wpdb->insert_id;

        return $id;
    }

    public static function update($data) {
        global $wpdb;
        $id = $data['id'];
        unset ($data['id']);

        $table = $wpdb->prefix . self::$table_name;

        $result = $wpdb->update( $table,
            $data,
            array( 'id' => $id )
        );

        return $id;
    }

    public static function delete($id) {
        global $wpdb;

        $table = $wpdb->prefix . self::$table_name;

        return $wpdb->delete( $table, array( 'id' => $id ) );
    }

    public static function deleteAll() {
        global $wpdb;

        $table = $wpdb->prefix . self::$table_name;

        $sql = "DELETE FROM {$table} WHERE 1=1";

        return $wpdb->query($sql);
    }

    public static function create_table() {
        global $wpdb;

        $wpdb->hide_errors();

        require_once(ABSPATH . 'wp-admin/includes/upgrade.php');

        dbDelta( self::get_schema() );
    }

    public static function get_rating_links_options() {
        $array = array(
            'wtsr_ts_review_link' => __('Trusted Shops review link', 'more-better-reviews-for-woocommerce'),
            'wtsr_product_url' => __('Product page link', 'more-better-reviews-for-woocommerce'),
            'wtsr_custom_link' => __('Custom review link', 'more-better-reviews-for-woocommerce'),
        );

        $array['wtsr_all_reviews_page'] = __('All products review page link', 'more-better-reviews-for-woocommerce');

        return $array;
    }

    public static function get_default_rating_links() {
        $wtsr_all_reviews_page = get_option('wtsr_all_reviews_page', false);

        if ($wtsr_all_reviews_page) {
            $is_page_exists = get_post($wtsr_all_reviews_page);

            if (empty($is_page_exists)) {
                delete_option('wtsr_all_reviews_page');
                $wtsr_all_reviews_page = false;
            }
        }

        return array(
            'one_star' => 'wtsr_all_reviews_page',
            'two_star' => 'wtsr_all_reviews_page',
            'three_star' => 'wtsr_all_reviews_page',
            'four_star' => 'wtsr_ts_review_link',
            'five_star' => 'wtsr_ts_review_link',
            'custom_link' => array (
                'one_star' => '',
                'two_star' => '',
                'three_star' => '',
                'four_star' => '',
                'five_star' => '',
            ),
        );
    }
}
