<?php


class Wtsr_Template {
    public static function get_email_plain_template($order_id, $review_link) {
        $plugin_url = untrailingslashit( plugins_url( '/', WTSR_PLUGIN_FILE ) );
        $order = wc_get_order( $order_id );

        if (!$order) {
            return '';
        }
        $order_items = TSManager::get_order_items($order);

        if (empty($order_items)) {
            return '';
        }

        $order_data = $order->get_data();
        $order_first_name = !empty($order_data['billing']['first_name']) ? $order_data['billing']['first_name'] : false;
        $order_last_name = !empty($order_data['billing']['last_name']) ? $order_data['billing']['last_name'] : false;
        $order_email = !empty($order_data['billing']['email']) ? $order_data['billing']['email'] : false;$default_rating_links = ReviewsModel::get_default_rating_links();
        $wtsr_rating_links = get_option('wtsr_rating_links', $default_rating_links);
        $wtsr_custom_rating_links = $wtsr_rating_links['custom_link'];
        $wtsr_all_reviews_page = get_option('wtsr_all_reviews_page', true);

        unset($wtsr_rating_links['custom_link']);

        $table_template = '';
        $length = 0;
        $table_template_length = 0;
        $star_review_title = TSManager::get_star_review_title();
        $is_woocommerce_only_mode = TSManager::is_woocommerce_only_mode();
        $is_woocommerce_reviews_disabled_globally = TSManager::is_woocommerce_reviews_disabled_globally();

        foreach ($order_items as $key => $item) {
            $id = $item['id'];
            $parent_id = !empty($item['parent_id']) ? $item['parent_id'] : $id;
            $slug = $item['slug'];
            $name = $item['name'];
            $post_content = $item['product_description'];
            $thumbnail = $item['thumbnail'];

            if (!$thumbnail) {
                $wtsr_image_size = TSManager::get_default_image_size();
                $thumbnail = wc_placeholder_img_src( $wtsr_image_size );
            }

            $star_ratings = array();

            $wtsr_rating_links_reverse = array_reverse($wtsr_rating_links);

            foreach ($wtsr_rating_links_reverse as $star => $rating_link) {
                if ($is_woocommerce_only_mode && 'wtsr_ts_review_link' === $rating_link) {
                    if ($wtsr_all_reviews_page) {
                        $rating_link = 'wtsr_all_reviews_page';
                    } else {
                        $rating_link = 'wtsr_product_url';
                    }
                }

                if ($is_woocommerce_reviews_disabled_globally && ('wtsr_product_url' === $rating_link || 'wtsr_all_reviews_page' === $rating_link)) {
                    $rating_link = 'wtsr_custom_link';
                }

                $link = '';

                if (defined('WTSR_PRESENTATION') && WTSR_PRESENTATION) {
                    $rating_link = 'wtsr_ts_review_link';
                }

                if ($wtsr_all_reviews_page && 'wtsr_all_reviews_page' === $rating_link) {
                    if (true === $wtsr_all_reviews_page || empty(get_post($wtsr_all_reviews_page))) {
                        $link = home_url( '/all-in-one-woo-review-page' );
                    } else {
                        $link = get_permalink( $wtsr_all_reviews_page );
                    }

                    $link .= '?id=' . $order_id . '_' . md5($order_email) . '&rating=' . $star . '&product_id=' . $id;
                } elseif ('wtsr_ts_review_link' === $rating_link) {
                    $link = $review_link;
                } elseif ('wtsr_product_url' === $rating_link) {
                    $link = get_permalink( $parent_id );
                    // $link = get_permalink( $id );
                    $link_parse = parse_url($link);
                    $query = 'ts_review=1';
                    $query .= '&ts_order_id=' . $order_id;
                    $query .= '&ts_rating=' . $star;

                    if (!empty($link_parse['query'])) {
                        $link .= '&' . $query;
                    } else {
                        $link .= '?' . $query;
                    }
                } elseif ('wtsr_custom_link' === $rating_link) {
                    $link = $wtsr_custom_rating_links[$star];
                    $link = str_replace('{order_number}', $order_id, $link);
                    $link = str_replace('{product_id}', $id, $link);
                    $link = str_replace('{product_slug}', $slug, $link);
                    $link = str_replace('{product_title}', $name, $link);

                    if (!empty($order_first_name)) {
                        $link = str_replace('{customer_fn}', $order_first_name, $link);
                    }

                    if (!empty($order_last_name)) {
                        $link = str_replace('{customer_ln}', $order_last_name, $link);
                    }
                    $link = str_replace('{customer_email}', $order_email, $link);
                }

                ob_start();
                ?>
                <?php echo $star_review_title[$star] ?>
                <?php echo $link; ?>
                <?php
                $star_item = ob_get_clean();

                $star_ratings[] = $star_item;
            }

            ob_start();
            ?>
            <?php echo '-------------------------------------' . PHP_EOL; ?>
            <?php echo $name . PHP_EOL; ?>
            <?php echo $post_content . PHP_EOL; ?>
            <?php echo '-------------------------------------' . PHP_EOL; ?>
            <?php echo __('Your rating', 'more-better-reviews-for-woocommerce') . ':' . PHP_EOL . PHP_EOL; ?>
            <?php echo implode('', $star_ratings); ?>
            <?php
            echo "=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=" . PHP_EOL . PHP_EOL;
            $table_template_part = ob_get_clean();

            $table_template_length = strlen($table_template) + strlen($table_template_part);
            $max_length = TSManager::get_max_email_template_length() - $length;

            if ($max_length > $table_template_length) {
                $table_template .= $table_template_part;
            }
        }

        return $table_template;
    }

    /**
     * @param object $review Review object
     */
    public static function preview_email_html_template($review) {
        if ('woocommerce' === TSManager::get_email_send_via()) {
            $order_id = $review->order_id;
            $order = wc_get_order( $order_id );

            if (!$order) {
                return '';
            }

            $order_data = $order->get_data();

            $order_first_name = !empty($order_data['billing']['first_name']) ? $order_data['billing']['first_name'] : '';
            $order_last_name = !empty($order_data['billing']['last_name']) ? $order_data['billing']['last_name'] : '';
            $link = $review->review_link;
            $message = $review->review_message;
            $wtsr_email_template_editor = get_option('wtsr_email_template', TSManager::get_default_email_template_editor());
            if (false !== strpos($wtsr_email_template_editor, '{order_number}')) {
                $wtsr_email_template_editor = str_replace( '{order_number}', $order_id, $wtsr_email_template_editor );
            }

            if (false !== strpos($wtsr_email_template_editor, '{customer_fn}')) {
                $wtsr_email_template_editor = str_replace( '{customer_fn}', $order_first_name, $wtsr_email_template_editor );
            }

            if (false !== strpos($wtsr_email_template_editor, '{customer_ln}')) {
                $wtsr_email_template_editor = str_replace( '{customer_ln}', $order_last_name, $wtsr_email_template_editor );
            }

            if (false !== strpos($wtsr_email_template_editor, '{order_date}')) {
                $wtsr_email_template_editor = str_replace( '{order_date}', $order_date_created = $order_data['date_created']->date(get_option( 'date_format' )), $wtsr_email_template_editor );
            }

            if (false !== strpos($wtsr_email_template_editor, '{order_items_table}')) {
                $order_items_table = TSManager::get_order_items_table_template($order_id, $link, 0);

                $wtsr_email_template_editor = str_replace( '{order_items_table}', $order_items_table, $wtsr_email_template_editor );
            }

            if (false !== strpos($wtsr_email_template_editor, '{order_items_table_one_col}')) {
                $order_items_table = TSManager::get_order_items_table_one_col_template($order_id, $link, 0);

                $wtsr_email_template_editor = str_replace( '{order_items_table_one_col}', $order_items_table, $wtsr_email_template_editor );
            }
            echo wpautop($wtsr_email_template_editor);
        } else {
            echo wpautop($review->review_message);
        }
    }
}