<?php

/**
 * The plugin bootstrap file
 *
 * @since             0.0.1
 * @package           Wtsr
 *
 * @wordpress-plugin
 * Plugin Name:       Get Better Reviews for WooCommerce
 * Plugin URI:        https://saleswonder.biz/blog/bessere-bewertungen-fuer-woocommerce/
 * Description:       Get Better Reviews for WooCommerce is an automated reviews request system for WooCommerce reviews
 * Version:           2.0.4
 * Author:            Tobias Conrad
 * Author URI:        https://saleswonder.biz/
 * Requires at least: 4.9
 * Tested up to: 5.3
 * WC requires at least: 3.4
 * WC tested up to: 3.8
 * Requires at least WooCommerce: 3.4
 * Tested up to WooCommerce: 3.8
 *
 * Text Domain:       more-better-reviews-for-woocommerce
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 0.0.1 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'WTSR_VERSION', '2.0.4' );

// Define WC_PLUGIN_FILE.
if ( ! defined( 'WTSR_PLUGIN_FILE' ) ) {
    define( 'WTSR_PLUGIN_FILE', __FILE__ );
}

define( 'WTSR_PRESENTATION', false );
define( 'WTSR_BRANCH', 'master' );

// Core functions
require_once( 'includes/functions.php' );

/**
 * WP2LEADS fallback notice.
 *
 * @since 0.0.1
 * @return string
 */
function wtsr_wp2leads_notice() {
    /* translators: 1. URL link. */
    echo '<div class="error"><p><strong>' . sprintf( esc_html__( 'If you like to sent review request to Klick Tipp plugin requires WP2LEADS plugin to be installed and active. You can download %s here.', 'more-better-reviews-for-woocommerce' ), '<a href="https://wp2leads-for-klick-tipp.com/woo-wp4free/pop-verbinde-woo-wp-fuer-lau/" target="_blank">WP2LEADS</a>' ) . '</strong></p></div>';
}

/**
 * WP2LEADS fallback notice.
 *
 * @since 0.0.1
 * @return string
 */
function wtsr_woocommerce_notice() {
    /* translators: 1. URL link. */
    echo '<div class="error"><p><strong>' . sprintf( esc_html__( 'WooCommerce Trusted Shops Reviews requires WooCommerce plugin to be installed and active. You can download %s here.', 'more-better-reviews-for-woocommerce' ), '<a href="https://woocommerce.com/" target="_blank">Woocommerce</a>' ) . '</strong></p></div>';
}

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-wtsr-activator.php
 */
function activate_wtsr() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-wtsr-activator.php';
	Wtsr_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-wtsr-deactivator.php
 */
function deactivate_wtsr() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-wtsr-deactivator.php';
	Wtsr_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_wtsr' );
register_deactivation_hook( __FILE__, 'deactivate_wtsr' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-wtsr.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    0.0.1
 */
function run_wtsr() {

	$plugin = new Wtsr();
	$plugin->run();

}
run_wtsr();
